@@ -2,11 +2,11 @@
 
 use std::collections::BTreeMap;
 use std::convert::TryInto;
+use std::time::Duration;
 
 use serde::Serialize;
 
-use tokio::time::delay_for;
-use tokio::time::Duration;
+use tokio::time::sleep;
 
 use crate::Error;
 mod payload;
@@ -28,35 +28,6 @@ use torrent::GetTorrentFilesResponse;
 /// including adding, and removing torrents.
 ///
 /// The `Client` does not keep track of the created torrents itself.
-///
-/// Example of creating a session and adding a torrent and waiting for it to complete.
-/// ```no_run
-/// use transmission::{ ClientConfig, Client};
-///
-/// # let test_dir = "/tmp/tr-test-long";
-/// # let config_dir = test_dir;
-/// # let download_dir = test_dir;
-/// let file_path = "./alpine.torrent";
-///
-/// # std::fs::create_dir(test_dir).unwrap();
-///
-/// let c = ClientConfig::new()
-///    .app_name("testing")
-///    .config_dir(config_dir)
-///    .download_dir(download_dir);
-/// let mut c = Client::new(c);
-///
-/// let t = c.add_torrent_file(file_path).unwrap();
-/// t.start();
-///
-/// // Run until done
-/// while t.stats().percent_complete < 1.0 {
-///     print!("{:#?}\r", t.stats().percent_complete);
-/// }
-/// c.close();
-///
-/// # std::fs::remove_dir_all(test_dir).unwrap();
-/// ```
 #[derive(Clone)]
 pub struct Client {
 	host: String,
@@ -131,7 +102,7 @@ impl Client {
 		let request = Request::new(method, tag, body);
 		let mut error = None;
 		for i in 0..5 {
-			delay_for(Duration::from_secs(i)).await;
+			sleep(Duration::from_secs(i)).await;
 			let result = self.post("/transmission/rpc/")
 				// Content-Type doesn't actually appear to be necessary, and is
 				//    technically a lie, since there's no key/value being passed,
@@ -208,8 +179,7 @@ impl Client {
 		} else if(response.arguments.torrents.len() > 1) {
 			return Err(Error::WeirdGetFilesResponse);
 		}
-		// TODO:  Figure out how to move files out of this structure, since we're discarding the rest anyway, instead of cloning
-		Ok(response.arguments.torrents[0].files.clone())
+		Ok(response.arguments.torrents.into_iter().next().unwrap().files)
 	}
 }
 
